@@ -930,7 +930,8 @@ class OpenApiResponse(JSONDetector):
         """
         Finds the correct SchemaObject for a particular content type. Handles
         the asterisk "*" character that is used to group media types into ranges
-        (https://www.rfc-editor.org/rfc/rfc7231#section-5.3.2)
+        (https://www.rfc-editor.org/rfc/rfc7231#section-5.3.2). Also handles
+        parameters in the form of name=value pairs.
         """
         media_types = self.content.keys()
         matched_media_type = OpenApiResponse.match_content_type(
@@ -959,8 +960,9 @@ class OpenApiResponse(JSONDetector):
             elif '/' in media_type:
                 type_, subtype = media_type.split('/')
                 if (type_ == '*' or type_ == content_type.split('/')[0]) and \
-                (subtype == '*' or subtype == content_type.split('/')[1]):
+                (subtype == '*' or subtype == content_type.split('/')[1].split(';')[0]):
                     return media_type
+
         return None
 
     def deserialize(self, response: ResponseWrapper, configuration: Configuration, skip_deserialization = False) -> ApiResponse:
@@ -1035,9 +1037,7 @@ class ApiClient:
     the methods and models for each application are generated from the OpenAPI
     templates.
 
-    NOTE: This class is auto generated by Konfig.
-    Ref: https://konfigthis.com
-    Do not edit the class manually.
+    This class is auto generated
 
     :param configuration: .Configuration object for this client
     :param header_name: a header to pass when making calls to the API.
@@ -1070,7 +1070,7 @@ class ApiClient:
             self.default_headers[header_name] = header_value
         self.cookie = cookie
         # Set default User-Agent.
-        self.user_agent = 'Konfig/4.1.0/python'
+        self.user_agent = 'Konfig/4.2.0/python'
 
     def __enter__(self):
         return self
@@ -1179,6 +1179,8 @@ class ApiClient:
             stream=stream,
             timeout=timeout,
         )
+
+
         return response
 
     def call_api(
@@ -1376,10 +1378,8 @@ class ApiClient:
 
 
 class Api:
-    """NOTE: This class is auto generated by Konfig
-    Ref: https://konfigthis.com
-
-    Do not edit the class manually.
+    """NOTE:
+    This class is auto generated
     """
 
     def __init__(self, api_client: typing.Optional[ApiClient] = None):
